@@ -20,6 +20,10 @@ testthat::test_that("output from autoplot is of class gg, ggplot", {
   testthat::expect_s3_class(object = autoplot(single, type = "se"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(single, type = "est_ba"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(single, type = "se_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(single, type = "est_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(single, type = "se_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(single, type = "est_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(single, type = "se_hex"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(single, type = "est_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(single, type = "se_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(single, type = "heat"), class = c("gg", "ggplot"))
@@ -32,6 +36,10 @@ testthat::test_that("output from autoplot is of class gg, ggplot", {
   testthat::expect_s3_class(object = autoplot(multi, type = "se"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(multi, type = "est_ba"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(multi, type = "se_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multi, type = "est_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multi, type = "se_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multi, type = "est_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multi, type = "se_hex"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(multi, type = "est_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(multi, type = "se_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(multi, type = "heat"), class = c("gg", "ggplot"))
@@ -44,6 +52,10 @@ testthat::test_that("output from autoplot is of class gg, ggplot", {
   testthat::expect_s3_class(object = autoplot(singlesum, type = "se"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(singlesum, type = "est_ba"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(singlesum, type = "se_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "est_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "se_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "est_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "se_hex"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(singlesum, type = "est_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(singlesum, type = "se_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(singlesum, type = "heat"), class = c("gg", "ggplot"))
@@ -56,6 +68,10 @@ testthat::test_that("output from autoplot is of class gg, ggplot", {
   testthat::expect_s3_class(object = autoplot(multisum, type = "se"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(multisum, type = "est_ba"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(multisum, type = "se_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multisum, type = "est_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multisum, type = "se_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multisum, type = "est_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multisum, type = "se_hex"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(multisum, type = "est_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(multisum, type = "se_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(multisum, type = "heat"), class = c("gg", "ggplot"))
@@ -83,6 +99,10 @@ testthat::test_that("argument checks works throws errors when appropriate", {
   testthat::expect_error(object = print(autoplot(single, scales = "either")))
   testthat::expect_error(object = print(autoplot(single, top = 0)))
   testthat::expect_error(object = print(autoplot(single, top = "Yes!")))
+  testthat::expect_error(object = print(autoplot(single, density.legend = 0)))
+  testthat::expect_error(object = print(autoplot(single, density.legend = "Bamboozled")))
+  testthat::expect_error(object = print(autoplot(single, zoom = TRUE)))
+  testthat::expect_error(object = print(autoplot(single, zoom = "Why not?")))
   # simsum object, with 'by'
   testthat::expect_error(object = print(autoplot(multi, type = "megacool_plot")))
   testthat::expect_error(object = print(autoplot(multi, type = 1)))
@@ -101,6 +121,10 @@ testthat::test_that("argument checks works throws errors when appropriate", {
   testthat::expect_error(object = print(autoplot(multi, scales = "either")))
   testthat::expect_error(object = print(autoplot(multi, top = 0)))
   testthat::expect_error(object = print(autoplot(multi, top = "Yes!")))
+  testthat::expect_error(object = print(autoplot(multi, density.legend = 0)))
+  testthat::expect_error(object = print(autoplot(multi, density.legend = "Bamboozled")))
+  testthat::expect_error(object = print(autoplot(multi, zoom = TRUE)))
+  testthat::expect_error(object = print(autoplot(multi, zoom = "Why not?")))
   # summary.simsum object, no 'by'
   testthat::expect_error(object = print(autoplot(singlesum, type = "megacool_plot")))
   testthat::expect_error(object = print(autoplot(singlesum, type = 1)))
@@ -119,6 +143,10 @@ testthat::test_that("argument checks works throws errors when appropriate", {
   testthat::expect_error(object = print(autoplot(singlesum, scales = "either")))
   testthat::expect_error(object = print(autoplot(singlesum, top = 0)))
   testthat::expect_error(object = print(autoplot(singlesum, top = "Yes!")))
+  testthat::expect_error(object = print(autoplot(singlesum, density.legend = 0)))
+  testthat::expect_error(object = print(autoplot(singlesum, density.legend = "Bamboozled")))
+  testthat::expect_error(object = print(autoplot(singlesum, zoom = TRUE)))
+  testthat::expect_error(object = print(autoplot(singlesum, zoom = "Why not?")))
   # summary.simsum object, with 'by'
   testthat::expect_error(object = print(autoplot(multisum, type = "megacool_plot")))
   testthat::expect_error(object = print(autoplot(multisum, type = 1)))
@@ -137,6 +165,10 @@ testthat::test_that("argument checks works throws errors when appropriate", {
   testthat::expect_error(object = print(autoplot(multisum, scales = "either")))
   testthat::expect_error(object = print(autoplot(multisum, top = 0)))
   testthat::expect_error(object = print(autoplot(multisum, top = "Yes!")))
+  testthat::expect_error(object = print(autoplot(multisum, density.legend = 0)))
+  testthat::expect_error(object = print(autoplot(multisum, density.legend = "Bamboozled")))
+  testthat::expect_error(object = print(autoplot(multisum, zoom = TRUE)))
+  testthat::expect_error(object = print(autoplot(multisum, zoom = "Why not?")))
 })
 
 testthat::test_that("autoplot with target", {
@@ -218,6 +250,32 @@ testthat::test_that("autoplot with top", {
   testthat::expect_s3_class(object = autoplot(nlpssum, type = "nlp", top = FALSE), class = c("gg", "ggplot"))
 })
 
+testthat::test_that("autoplot with density.legend", {
+  # density plot
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "est_density", density.legend = TRUE), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "se_density", density.legend = TRUE), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "est_density", density.legend = FALSE), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "se_density", density.legend = FALSE), class = c("gg", "ggplot"))
+  # hex plot
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "est_hex", density.legend = TRUE), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "se_hex", density.legend = TRUE), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "est_hex", density.legend = FALSE), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "se_hex", density.legend = FALSE), class = c("gg", "ggplot"))
+  # summary.simsum object, with 'by'
+  testthat::expect_s3_class(object = autoplot(multisum, scales = "fixed"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multisum, scales = "free"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multisum, scales = "free_x"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multisum, scales = "free_y"), class = c("gg", "ggplot"))
+})
+
+testthat::test_that("autoplot with zoom", {
+  # nested loop plot
+  testthat::expect_s3_class(object = autoplot(single, type = "zip", zoom = 0.5), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(singlesum, type = "zip", zoom = 0.5), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multi, type = "zip", zoom = 0.5), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(multisum, type = "zip", zoom = 0.5), class = c("gg", "ggplot"))
+})
+
 testthat::test_that("inferring target", {
   # simsum object, no 'by'
   testthat::expect_s3_class(object = autoplot(single, stats = "bias"), class = c("gg", "ggplot"))
@@ -313,6 +371,10 @@ testthat::test_that("output from autoplot is of class gg, ggplot", {
   testthat::expect_s3_class(object = autoplot(ms, par = "trt", type = "se"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(ms, par = "trt", type = "est_ba"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(ms, par = "trt", type = "se_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(ms, par = "trt", type = "est_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(ms, par = "trt", type = "se_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(ms, par = "trt", type = "est_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(ms, par = "trt", type = "se_hex"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(ms, par = "trt", type = "est_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(ms, par = "trt", type = "se_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(ms, par = "trt", type = "heat"), class = c("gg", "ggplot"))
@@ -325,6 +387,10 @@ testthat::test_that("output from autoplot is of class gg, ggplot", {
   testthat::expect_s3_class(object = autoplot(ms2, par = "trt", type = "se"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(ms2, par = "trt", type = "est_ba"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(ms2, par = "trt", type = "se_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(ms2, par = "trt", type = "est_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(ms2, par = "trt", type = "se_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(ms2, par = "trt", type = "est_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(ms2, par = "trt", type = "se_hex"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(ms2, par = "trt", type = "est_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(ms2, par = "trt", type = "se_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(ms2, par = "trt", type = "heat"), class = c("gg", "ggplot"))
@@ -338,6 +404,10 @@ testthat::test_that("output from autoplot is of class gg, ggplot", {
   testthat::expect_s3_class(object = autoplot(sms, par = "trt", type = "se"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(sms, par = "trt", type = "est_ba"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(sms, par = "trt", type = "se_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(sms, par = "trt", type = "est_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(sms, par = "trt", type = "se_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(sms, par = "trt", type = "est_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(sms, par = "trt", type = "se_hex"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(sms, par = "trt", type = "est_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(sms, par = "trt", type = "se_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(sms, par = "trt", type = "heat"), class = c("gg", "ggplot"))
@@ -350,6 +420,10 @@ testthat::test_that("output from autoplot is of class gg, ggplot", {
   testthat::expect_s3_class(object = autoplot(sms2, par = "trt", type = "se"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(sms2, par = "trt", type = "est_ba"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(sms2, par = "trt", type = "se_ba"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(sms2, par = "trt", type = "est_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(sms2, par = "trt", type = "se_density"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(sms2, par = "trt", type = "est_hex"), class = c("gg", "ggplot"))
+  testthat::expect_s3_class(object = autoplot(sms2, par = "trt", type = "se_hex"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(sms2, par = "trt", type = "est_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(sms2, par = "trt", type = "se_ridge"), class = c("gg", "ggplot"))
   testthat::expect_s3_class(object = autoplot(sms2, par = "trt", type = "heat"), class = c("gg", "ggplot"))
